Struct Operand
pub struct Operand<'a, P>where
P: Paragraph,{
pub paragraph: &'a mut Plain<P>,
pub layout: Layout,
pub selectable: bool,
}Available on crate feature
advanced only.Expand description
The state of a widget with text, operated on by super::Operation::text.
Fields
paragraph: &'a mut Plain<P>The Paragraph of the widget.
layout: LayoutThe layout of the widget.
selectable: boolWhether the text of the widget can be selected.